import Layout from '@/layout'
// 仪器管理路由 instrument
const instrumentRouter = [
  {
    path: '/instrument/mainoverview',
    component: Layout,
    redirect: '/instrument/mainoverview/index',
    meta: { classification: 'instrument', module_code: 'MainOverview' },
    children: [
      {
        path: 'index',
        name: 'standardMainOverview',
        meta: { title: '主预览', icon: '主概览', classification: 'instrument' },
        component: () => import('@/views/reagent/mainoverview/index')
      }
    ]
  },
  {
    path: '/instrument/report',
    component: Layout,
    redirect: '/instrument/report/index',
    meta: { classification: 'instrument', module_code: 'DataReportIndex' },
    children: [
      {
        path: 'index',
        name: 'standardReport',
        component: () => import('@/views/reagent/report/index'),
        meta: { title: '报告统计', icon: '报表统计', classification: 'instrument' }
      },
      {
        path: 'storeinfo',
        name: 'standardStoreInfo',
        component: () => import('@/views/reagent/report/storeinfo/index'),
        hidden: true,
        meta: { title: '库存信息总览', icon: '报表统计', classification: 'instrument', activeMenu: '/instrument/report/index' }
      },
      {
        path: 'standardinfo',
        name: 'standardInfo',
        component: () => import('@/views/reagent/report/reagentinfo/index'),
        hidden: true,
        meta: { title: '仪器信息详情', icon: '报表统计', classification: 'instrument', activeMenu: '/instrument/report/index' }
      },
      {
        path: 'warehousinginfo',
        name: 'standardWarehousingInfo',
        component: () => import('@/views/reagent/report/warehousinginfo/index'),
        hidden: true,
        meta: { title: '入库信息查询', icon: '报表统计', classification: 'instrument', activeMenu: '/instrument/report/index' }
      },
      {
        path: 'inventoryconsuminfo',
        name: 'standardInventoryConsumInfo',
        component: () => import('@/views/reagent/report/inventoryconsum/index'),
        hidden: true,
        meta: { title: '库存消耗', icon: '报表统计', classification: 'instrument', activeMenu: '/instrument/report/index' }
      },
      {
        path: 'standardconsuminfo',
        name: 'standardConsumInfo',
        component: () => import('@/views/reagent/report/reagentconsum/index'),
        hidden: true,
        meta: { title: '仪器消耗', icon: '报表统计', classification: 'instrument', activeMenu: '/instrument/report/index' }
      },
      {
        path: 'userconsuminfo',
        name: 'standardUserConsumInfo',
        component: () => import('@/views/reagent/report/userconsum/index'),
        hidden: true,
        meta: { title: '人员用量消耗', icon: '报表统计', classification: 'instrument', activeMenu: '/instrument/report/index' }
      },
      {
        path: 'usefrequencyinfo',
        name: 'standardUseFrequencyInfo',
        component: () => import('@/views/reagent/report/usefrequency/index'),
        hidden: true,
        meta: { title: '使用频率', icon: '报表统计', classification: 'instrument', activeMenu: '/instrument/report/index' }
      },
      {
        path: 'recordinfo/:t',
        name: 'standardRecordInfo',
        component: () => import('@/views/reagent/report/record/index'),
        hidden: true,
        meta: { title: '记录', icon: '报表统计', classification: 'instrument', activeMenu: '/instrument/report/index' }
      }
    ]
  },
  {
    path: '/instrument/warehousing',
    component: Layout,
    redirect: '/instrument/warehousing/index',
    meta: { classification: 'instrument', module_code: 'InstrumentTemplateIndex' },
    children: [
      {
        path: 'index',
        name: 'standardWarehousing',
        component: () => import('@/views/reagent/warehousing/index'),
        meta: { title: '仪器入库', icon: '试剂入库', classification: 'instrument' }
      }
    ]
  },
  {
    path: '/instrument/receiving',
    component: Layout,
    redirect: '/instrument/receiving/index',
    meta: { classification: 'instrument', module_code: 'InstrumentUseView' },
    children: [
      {
        path: 'index',
        name: 'standardReceiving',
        component: () => import('@/views/reagent/receivingandreturn/index'),
        meta: { title: '仪器领用', icon: '试剂领用', classification: 'instrument' }
      }
    ]
  },
  {
    path: '/instrument/sendback',
    component: Layout,
    redirect: '/instrument/sendback/index',
    meta: { classification: 'instrument', module_code: 'InstrumentReturnView' },
    children: [
      {
        path: 'index',
        name: 'standardSendBack',
        component: () => import('@/views/reagent/receivingandreturn/index'),
        meta: { title: '仪器归还', icon: '试剂归还', classification: 'instrument' }
      }
    ]
  },
  {
    path: '/instrument/weighing',
    component: Layout,
    redirect: '/instrument/weighing/index',
    meta: { classification: 'instrument', module_code: 'InstrumentWeigh' },
    children: [
      {
        path: 'index',
        name: 'standardweighing',
        component: () => import('@/views/reagent/weighing/index'),
        meta: { title: '仪器称重', icon: '试剂称重', classification: 'instrument' }
      }
    ]
  },
  {
    path: '/instrument/inventory',
    component: Layout,
    redirect: '/instrument/inventory/index',
    meta: { classification: 'instrument', module_code: 'StockTakingIndex' },
    children: [
      {
        path: 'index',
        name: 'standardInventory',
        component: () => import('@/views/reagent/inventory/index'),
        meta: { title: '仪器盘点', icon: '库存盘点', classification: 'instrument' }
      }
    ]
  },
  {
    path: '/instrument/database',
    component: Layout,
    redirect: '/instrument/database/msds',
    meta: { title: '化学品数据库', icon: '化学品数据库', classification: 'instrument', module_code: 'ChemicaDatabase' },
    children: [
      {
        path: 'msds',
        name: 'standardMSDS',
        component: () => import('@/views/reagent/database/index'),
        meta: { title: 'MSDS数据库', classification: 'instrument' }
      },
      {
        path: 'dangerous',
        name: 'standardDangerous',
        component: () => import('@/views/reagent/database/index'),
        meta: { title: '危化品数据库', classification: 'instrument' }
      }
    ]
  },
  {
    path: '/instrument/management',
    component: Layout,
    redirect: '/instrument/management/index',
    meta: { title: '仪器管理', classification: 'instrument', icon: '试剂管理', module_code: 'InstrumentIndex' },
    children: [
      {
        path: 'index',
        name: 'standardManagement',
        component: () => import('@/views/reagent/management/data/index'),
        meta: { title: '仪器管理', icon: '试剂管理', classification: 'instrument' }
      }
    ]
  },
  {
    path: '/instrument/client',
    component: Layout,
    redirect: '/instrument/client/index',
    meta: { classification: 'instrument', module_code: 'CabinetIndex' },
    children: [
      {
        path: 'index',
        name: 'standardClient',
        component: () => import('@/views/reagent/client/index'),
        meta: { title: '柜体管理', icon: '柜体管理', classification: 'instrument' }
      }
    ]
  },
  {
    path: '/instrument/envrecord',
    component: Layout,
    redirect: '/instrument/envrecord/index',
    meta: { classification: 'instrument', module_code: 'HumitureIndex' },
    children: [
      {
        path: 'index',
        name: 'standardEnvRecord',
        component: () => import('@/views/reagent/envrecord/index'),
        meta: { title: '环境记录', icon: '雪花', classification: 'instrument' }
      }
    ]
  },
  {
    path: '/instrument/form',
    component: Layout,
    redirect: '/instrument/form/index',
    meta: { classification: 'instrument', module_code: 'InstrumentCustomForm' },
    children: [
      {
        path: 'index',
        name: 'standardForm',
        component: () => import('@/views/reagent/customform/index'),
        meta: { title: '仪器表单自定义', icon: '表单', classification: 'instrument' }
      }
    ]
  },
  // {
  //   path: '/standard/buy',
  //   component: Layout,
  //   meta: { classification: 'standard' },
  //   children: [
  //     {
  //       path: 'index',
  //       name: 'Buy',
  //       component: () => import('@/views/reagent/buy/index'),
  //       meta: { title: '请购', icon: '请购', classification: 'standard' }
  //     }
  //   ]
  // },
  {
    path: '/instrument/gotohome',
    redirect: '/home',
    meta: { title: '返回主页', icon: 'el-icon-arrow-left', classification: 'instrument' }
  }
]

export default instrumentRouter
